"use strict";
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
Object.defineProperty(exports, "__esModule", { value: true });
var axios_1 = require("axios");
var DEFAULT_CONFIG = {
    timeout: 5000,
    withCredentials: true,
    validateStatus: function (status) { return status >= 200 && status < 599; },
};
var Http = /** @class */ (function () {
    function Http(baseUrl, config) {
        if (config === void 0) { config = {}; }
        this.authorizationToken = '';
        this.cancelToken = axios_1.default.CancelToken;
        this.source = this.cancelToken.source();
        var axiosIns = axios_1.default.create(__assign({ baseURL: baseUrl }, DEFAULT_CONFIG, config));
        Http.INSTANCES[baseUrl] = axiosIns;
        this.axiosIns = axiosIns;
    }
    Http.prototype.setAuthorizationTypeOrToken = function (type, token) {
        this.authorizationToken = token;
        this.authorizationType = type;
    };
    Http.prototype.request = function (opt) {
        var _opt = Object.assign(null, opt);
        _opt.headers = __assign({}, _opt.headers, { authorization_type: this.authorizationType, authorization_token: this.authorizationToken });
        _opt.cancelToken = this.source.token;
        return this.axiosIns.request(_opt);
    };
    Http.prototype.abort = function () {
        this.source.cancel('API abort.');
    };
    Http.prototype.get = function (url, configs) {
        return this.request(__assign({ method: 'get', url: url }, configs));
    };
    Http.prototype.post = function (url, data, configs) {
        return this.request(__assign({ method: 'post', url: url,
            data: data, headers: {
                'Content-type': 'application/x-www-form-urlencoded'
            } }, configs));
    };
    Http.prototype.put = function (url, data, configs) {
        return this.request(__assign({ method: 'put', url: url,
            data: data }, configs));
    };
    Http.prototype.patch = function (url, data, configs) {
        return this.request(__assign({ method: 'patch', url: url,
            data: data }, configs));
    };
    Http.prototype.delete = function (url, configs) {
        return this.request(__assign({ method: 'delete', url: url }, configs));
    };
    // 下面是静态方法
    Http.getInstances = function (key) {
        return Http.INSTANCES[key];
    };
    Http.setReqInterceptor = function (resolve, reject) {
        for (var key in Http.INSTANCES) {
            var instance = Http.INSTANCES[key];
            instance.interceptors.request.use(resolve, reject);
        }
    };
    Http.setResInterceptor = function (resolve, reject) {
        for (var key in Http.INSTANCES) {
            var instance = Http.INSTANCES[key];
            instance.interceptors.response.use(resolve, reject);
        }
    };
    Http.INSTANCES = {};
    return Http;
}());
exports.default = Http;
//# sourceMappingURL=mlz_axios.js.map