(function (global, factory) {
    typeof exports === 'object' && typeof module !== 'undefined' ? module.exports = factory(require('axios')) :
    typeof define === 'function' && define.amd ? define(['axios'], factory) :
    (global = global || self, global.mlzAxios = factory(global.axios));
}(this, function (axios) { 'use strict';

    axios = axios && axios.hasOwnProperty('default') ? axios['default'] : axios;

    /*! *****************************************************************************
    Copyright (c) Microsoft Corporation. All rights reserved.
    Licensed under the Apache License, Version 2.0 (the "License"); you may not use
    this file except in compliance with the License. You may obtain a copy of the
    License at http://www.apache.org/licenses/LICENSE-2.0

    THIS CODE IS PROVIDED ON AN *AS IS* BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
    KIND, EITHER EXPRESS OR IMPLIED, INCLUDING WITHOUT LIMITATION ANY IMPLIED
    WARRANTIES OR CONDITIONS OF TITLE, FITNESS FOR A PARTICULAR PURPOSE,
    MERCHANTABLITY OR NON-INFRINGEMENT.

    See the Apache Version 2.0 License for specific language governing permissions
    and limitations under the License.
    ***************************************************************************** */

    var __assign = function() {
        __assign = Object.assign || function __assign(t) {
            for (var s, i = 1, n = arguments.length; i < n; i++) {
                s = arguments[i];
                for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p)) t[p] = s[p];
            }
            return t;
        };
        return __assign.apply(this, arguments);
    };

    var DEFAULT_CONFIG = {
        timeout: 5000,
        withCredentials: true,
        validateStatus: function (status) { return status >= 200 && status < 599; },
    };
    var Http = /** @class */ (function () {
        function Http(baseUrl, config) {
            if (config === void 0) { config = {}; }
            this.authorizationToken = '';
            this.cancelToken = axios.CancelToken;
            this.source = this.cancelToken.source();
            var axiosIns = axios.create(__assign({ baseURL: baseUrl }, DEFAULT_CONFIG, config));
            Http.INSTANCES[baseUrl] = axiosIns;
            this.axiosIns = axiosIns;
        }
        Http.prototype.setAuthorizationTypeOrToken = function (type, token) {
            this.authorizationToken = token;
            this.authorizationType = type;
        };
        Http.prototype.request = function (opt) {
            var _opt = Object.assign(null, opt);
            _opt.headers = __assign({}, _opt.headers, { authorization_type: this.authorizationType, authorization_token: this.authorizationToken });
            _opt.cancelToken = this.source.token;
            return this.axiosIns.request(_opt);
        };
        Http.prototype.abort = function () {
            this.source.cancel('API abort.');
        };
        Http.prototype.get = function (url, configs) {
            return this.request(__assign({ method: 'get', url: url }, configs));
        };
        Http.prototype.post = function (url, data, configs) {
            return this.request(__assign({ method: 'post', url: url,
                data: data, headers: {
                    'Content-type': 'application/x-www-form-urlencoded'
                } }, configs));
        };
        Http.prototype.put = function (url, data, configs) {
            return this.request(__assign({ method: 'put', url: url,
                data: data }, configs));
        };
        Http.prototype.patch = function (url, data, configs) {
            return this.request(__assign({ method: 'patch', url: url,
                data: data }, configs));
        };
        Http.prototype.delete = function (url, configs) {
            return this.request(__assign({ method: 'delete', url: url }, configs));
        };
        // 下面是静态方法
        Http.getInstances = function (key) {
            return Http.INSTANCES[key];
        };
        Http.setReqInterceptor = function (resolve, reject) {
            for (var key in Http.INSTANCES) {
                var instance = Http.INSTANCES[key];
                instance.interceptors.request.use(resolve, reject);
            }
        };
        Http.setResInterceptor = function (resolve, reject) {
            for (var key in Http.INSTANCES) {
                var instance = Http.INSTANCES[key];
                instance.interceptors.response.use(resolve, reject);
            }
        };
        Http.INSTANCES = {};
        return Http;
    }());

    return Http;

}));
//# sourceMappingURL=ts-axios.umd.js.map
